value property

T? get value

Current field value (may be null).

Implementation

T? get value => _value;
set value (T? next)

Updates value and notifies listeners when it changes.

When already in error, only clears the error if the new value passes validator (does not set new errors while the user edits).

Implementation

set value(T? next) => applyValueFromUser(next);